@@ -23,7 +23,7 @@
 #ifndef MODUTILS_MODULE_H
 #define MODUTILS_MODULE_H 1
 
-#ident "$Id: module.h 1.1 Fri, 05 Jan 2001 12:45:19 +1100 kaos $"
+#ident "$Id: module.h 1.2 Sat, 17 Nov 2001 22:41:24 +1100 kaos $"
 
 /* This file contains the structures used by the 2.0 and 2.1 kernels.
    We do not use the kernel headers directly because we do not wish
@@ -207,4 +207,13 @@ int delete_module(const char *);
  */
 extern unsigned int safemode;
 
+/*======================================================================*/
+/* Tainted kernel information.  This must match include/linux/kernel.h  */
+/* and kernel/panic.c.                                                  */
+
+#define TAINT_FILENAME			"/proc/sys/kernel/tainted"
+#define TAINT_PROPRIETORY_MODULE	(1<<0)
+#define TAINT_FORCED_MODULE		(1<<1)
+#define TAINT_UNSAFE_SMP		(1<<2)
+
 #endif /* module.h */
