@@ -21,7 +21,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ident "$Id: lsmod.c 1.2 Thu, 04 Oct 2001 16:33:23 +1000 kaos $"
+#ident "$Id: lsmod.c 1.3 Sat, 17 Nov 2001 22:41:24 +1100 kaos $"
 
 #include <stdio.h>
 #include <unistd.h>
@@ -80,7 +80,7 @@ int main(int argc, char **argv)
 			return 1;
 		}
 
-	if ((f = fopen("/proc/sys/kernel/tainted", "r"))) {
+	if ((f = fopen(TAINT_FILENAME, "r"))) {
 		fscanf(f, "%d", &tainted);
 		fclose(f);
 	}
@@ -89,9 +89,10 @@ int main(int argc, char **argv)
 	printf("Module                  Size  Used by    ");
 	if (f) {
 		if (tainted) {
-			printf("Tainted: %c%c",
-				tainted & 1 ? 'P' : 'G',
-				tainted & 2 ? 'F' : ' ');
+			printf("Tainted: %c%c%c",
+				tainted & TAINT_PROPRIETORY_MODULE	? 'P' : 'G',
+				tainted & TAINT_FORCED_MODULE		? 'F' : ' ',
+				tainted & TAINT_UNSAFE_SMP		? 'S' : ' ');
 		}
 		else
 			printf("Not tainted");
