@@ -35,7 +35,7 @@
  *   Keith Owens <kaos@ocs.com.au> September 2001.
  */
 
-#ident "$Id: modinfo.c 1.7 Tue, 25 Sep 2001 15:01:28 +1000 kaos $"
+#ident "$Id: modinfo.c 1.8 Wed, 26 Sep 2001 11:58:34 +1000 kaos $"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -168,7 +168,7 @@ static int append_modinfo_tag(struct obj_file *f, char *tag, char *def,
 	if (strlen(p)+extra < n)
 		n = strlen(p)+extra;
 
-	if (!multi_line || n <= 2) {
+	if (!multi_line || n < 2) {
 		strncpy(*out_str, p, n);
 		*out_str += n;
 	}
