@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_common.c 1.3 Sat, 22 Sep 2001 20:06:32 +1000 kaos $"
+#ident "$Id: obj_common.c 1.4 Wed, 26 Sep 2001 11:58:34 +1000 kaos $"
 
 #include <stdlib.h>
 #include <string.h>
@@ -263,7 +263,7 @@ obj_load_order_prio(struct obj_section *a)
 	.bss    0 0  0  */
   if (strcmp (a->name, ".got") == 0) ac |= 2;
   if (af & ARCH_SHF_SHORT)
-    ac = ac & ~4 | 1;
+    ac = (ac & ~4) | 1;
 
   return ac;
 }
