@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_i386.c 1.2 Sat, 22 Sep 2001 20:06:32 +1000 kaos $"
+#ident "$Id: obj_i386.c 1.3 Wed, 26 Sep 2001 14:50:45 +1000 kaos $"
 
 #include <string.h>
 #include <assert.h>
@@ -183,9 +183,7 @@ arch_create_got (struct obj_file *f)
 
       for (; rel < relend; ++rel)
 	{
-	  Elf32_Sym *extsym;
 	  struct i386_symbol *intsym;
-	  const char *name;
 
 	  switch (ELF32_R_TYPE(rel->r_info))
 	    {
@@ -199,12 +197,7 @@ arch_create_got (struct obj_file *f)
 	      break;
 	    }
 
-	  extsym = &symtab[ELF32_R_SYM(rel->r_info)];
-	  if (extsym->st_name)
-	    name = strtab + extsym->st_name;
-	  else
-	    name = f->sections[extsym->st_shndx]->name;
-	  intsym = (struct i386_symbol *)obj_find_symbol(&ifile->root, name);
+	  obj_find_relsym(intsym, f, &ifile->root, rel, symtab, strtab);
 
 	  if (!intsym->gotent.offset_done)
 	    {
