@@ -19,7 +19,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ident "$Id: obj_ia64.c 1.3 Wed, 26 Sep 2001 14:50:45 +1000 kaos $"
+#ident "$Id: obj_ia64.c 1.4 Thu, 31 Jan 2002 23:42:50 +1100 kaos $"
 
 #include <string.h>
 #include <assert.h>
@@ -255,14 +255,15 @@ obj_ia64_ins_imm64(Elf64_Xword v, Elf64_Addr *bundle, Elf64_Xword slot)
 {
     Elf64_Xword ins;
 
-    assert(slot == 1);
+    assert(slot == 2);
+
     ins = obj_ia64_ins_extract_from_bundle(bundle, slot);
-    ins &= 0xffffffee000101ff;
-    ins |= ((v & 0x8000000000000000) >> 28) | ((v & 0x0000000000200000)) |
+    ins &= 0xffffffe000101fff;
+    ins |= ((v & 0x8000000000000000) >> 27) | ((v & 0x0000000000200000)) |
 	   ((v & 0x00000000001f0000) <<  6) | ((v & 0x000000000000ff80) << 20) |
 	   ((v & 0x000000000000007f) << 13);
     obj_ia64_ins_insert_in_bundle(bundle, slot, ins);
-    obj_ia64_ins_insert_in_bundle(bundle, ++slot, ((v & 0x7fffffffffc00000) >> 22));
+    obj_ia64_ins_insert_in_bundle(bundle, --slot, ((v & 0x7fffffffffc00000) >> 22));
     return obj_reloc_ok;
 }
 
