@@ -23,7 +23,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_s390x.c 1.2 Sat, 22 Sep 2001 20:06:32 +1000 kaos $"
+#ident "$Id: obj_s390x.c 1.3 Wed, 26 Sep 2001 14:50:45 +1000 kaos $"
 
 #include <string.h>
 #include <assert.h>
@@ -273,13 +273,9 @@ arch_create_got (struct obj_file *f)
 
       for (; rel < relend; ++rel)
        {
-         Elf64_Sym *extsym;
          struct s390_symbol *intsym;
           struct s390_plt_entry *pe;
           struct s390_got_entry *ge;
-         const char *name;
-
-          extsym = &symtab[ELF64_R_SYM(rel->r_info)];
 
          switch (ELF64_R_TYPE(rel->r_info)) {
             /* These four relocations refer to a plt entry.  */
@@ -287,11 +283,7 @@ arch_create_got (struct obj_file *f)
             case R_390_PLT32:
             case R_390_PLT32DBL:
             case R_390_PLT64:
-              if (extsym->st_name)
-                name = strtab + extsym->st_name;
-              else
-                name = f->sections[extsym->st_shndx]->name;
-              intsym = (struct s390_symbol *) obj_find_symbol(f, name);
+	      obj_find_relsym(intsym, f, f, rel, symtab, strtab);
               assert(intsym);
               pe = &intsym->pltent;
               if (!pe->allocated) {
@@ -313,11 +305,7 @@ arch_create_got (struct obj_file *f)
            case R_390_GOT32:
             case R_390_GOT64:
             case R_390_GOTENT:
-              if (extsym->st_name)
-                name = strtab + extsym->st_name;
-              else
-                name = f->sections[extsym->st_shndx]->name;
-              intsym = (struct s390_symbol *) obj_find_symbol(f, name);
+	      obj_find_relsym(intsym, f, f, rel, symtab, strtab);
              assert(intsym);
               ge = (struct s390_got_entry *) &intsym->gotent;
               if (!ge->allocated) {
